Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(678)

Unified Diff: runtime/vm/class_finalizer.h

Issue 11348188: Ambiguous type references require a compile time error in some special cases (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/class_finalizer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/class_finalizer.h
===================================================================
--- runtime/vm/class_finalizer.h (revision 15232)
+++ runtime/vm/class_finalizer.h (working copy)
@@ -33,10 +33,13 @@
kDoNotResolve, // Type resolution is postponed.
kTryResolve, // Type resolution is attempted.
kFinalize, // Type resolution and type finalization are
- // required; a malformed type is tolerated.
+ // required; a malformed type is tolerated, since
+ // the type may be used as a type annotation.
kCanonicalize, // Same as kFinalize, but with canonicalization.
- kCanonicalizeForCreation, // Same as kCanonicalize, but do not tolerate
- // wrong number of type arguments.
+ kCanonicalizeExpression, // Same as kCanonicalize, but do not tolerate
+ // wrong number of type arguments or ambiguous
+ // type reference, since the type is not used as
+ // a type annotation, but as a type expression.
kCanonicalizeWellFormed // Error-free resolution, finalization, and
// canonicalization are required; a malformed
// type is not tolerated.
« no previous file with comments | « no previous file | runtime/vm/class_finalizer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698